@@ -9,6 +9,7 @@ from collections.abc import Mapping
 from typing import Optional,Dict,List,Union,Any
 from .codec import pack, unpack
 from functools import partial
+from concurrent.futures import CancelledError
 
 from contextvars import ContextVar
 processing = ContextVar("processing", default=None)
@@ -704,6 +705,10 @@ class Worker(BaseWorker):
             except Exception as exc:
                 self._kill_exc = exc
                 self._kill_flag.set()
+            except BaseException
+                self._kill_exc = CancelledError()
+                self._kill_flag.set()
+                raise
             finally:
                 self._persistent_nursery = None
 
